@@ -3,14 +3,71 @@ OC.L10N.register(
     {
     "_%n guest_::_%n guests_" : ["%n convidáu/ada","%n convidaos/es"],
     "Guest" : "Convidáu/ada",
+    "Invalid date, date format must be YYYY-MM-DD" : "Data non válida, el formatu ha ser AAAA-MM-DD",
+    "None" : "Dengún",
+    "User" : "Usuariu",
+    "Everyone" : "Toos",
+    "Disabled" : "Deshabilitáu",
+    "Users" : "Usuarios",
     "TURN server protocols" : "Protocolos del sirvidor TURN",
     "UDP and TCP" : "UDP y TCP",
     "UDP only" : "Namái UDP",
     "TCP only" : "Namái TCP",
+    "Copy link" : "Copiar enllaz",
+    "No other people in this call" : "Nun hai más xente nesta llamada",
+    "Waiting for others to join the call …" : "Esperando que los otros se xunan a la llamada...",
+    "Show your screen" : "Amosar la to pantalla",
+    "Stop screensharing" : "Parar compartición de pantalla",
+    "Enable screensharing" : "Activar compartición de pantalla",
+    "Screensharing requires the page to be loaded through HTTPS." : "La compartición de pantalla rique que les páxines carguen pente HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la to pantalla namái funciona con Firefox 52 o más mayor.",
+    "Screensharing extension is required to share your screen." : "Ríquese la estensión de compartición de pantalla pa compartir la to pantalla",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Usa un restolador distintu como Firefox o Chrome pa compartir la to pantalla, por favor.",
+    "An error occurred while starting screensharing." : "Asocedió un fallu entrín s'aniciaba la compartición de pantalla.",
+    "Your screen" : "La to pantalla",
+    "Disable video" : "Deshabilitar videu",
+    "Favorite" : "Marcar como favoritu",
+    "Remove from favorites" : "Remove from favorites",
+    "Add to favorites" : "Add to favorites",
+    "Contacts" : "Contautos",
+    "Groups" : "Grupos",
+    "Circles" : "Círculos",
+    "Loading" : "Cargando",
+    "Error" : "Fallu",
+    "Password protect" : "Protexer con contraseña",
+    "Back" : "Atrás",
+    "Close" : "Zarrar",
+    "Reply" : "Rempuesta",
+    "Today" : "Güei",
+    "Yesterday" : "Ayeri",
+    "guest" : "invitáu",
+    "No results" : "Ensin resultaos",
+    "Guests" : "Convidaos",
     "Share link" : "Compartir enllaz",
+    "Password protection" : "Password protection",
+    "Enter a password" : "Introduz una contraseña",
+    "Edit" : "Editar",
+    "Leave call" : "Dexar llamada",
+    "Limit to groups" : "Llendar a grupos",
+    "Save changes" : "Guardar camudancies",
+    "Saving …" : "Guardando...",
+    "Saved!" : "¡Guardóse!",
+    "Name" : "Nome",
+    "General settings" : "Axustes xenerales",
     "Saved" : "Guardóse",
+    "Password" : "Password",
+    "Cancel" : "Encaboxar",
+    "Submit" : "Unviar",
+    "Access to microphone & camera is only possible with HTTPS" : "L'accesu a la cámara y micrófonu namái ye posible con HTTPS",
+    "Access to microphone & camera was denied" : "Ñegóse l'accesu a la cámara y micrófonu",
+    "WebRTC is not supported in your browser" : "WebRTC nun ta sofitao nel to restolador",
+    "Please use a different browser like Firefox or Chrome" : "Usa un restoador distintu como Firefox o Chrome, por favor",
+    "Error while accessing microphone & camera" : "Fallu entrín s'accedia al micrófonu y cámara",
+    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
     "TURN server" : "Sirvidor TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El sirvidor TURN úsase pa unviar al proxy el tráficu de los participantes darrera de tornafueos.",
+    "Android app" : "Aplicación p'Android",
+    "iOS app" : "Aplicación pa iOS",
     "Delete server" : "Desaniciar sirvidor",
     "TURN server shared secret" : "Secretu compartíu del sirvidor TURN",
     "Copy" : "Copiar",
@@ -18,34 +75,22 @@ OC.L10N.register(
     "Not supported!" : "¡Nun se sofita!",
     "Press ⌘-C to copy." : "Primi ⌘-C pa copiar .",
     "Press Ctrl-C to copy." : "Primi Ctrl-C pa copiar.",
-    "Leave call" : "Dexar llamada",
+    "Share" : "Share",
+    "Change password" : "Camudar contraseña",
     "Rename" : "Renomar",
     "You" : "Tu",
-    "No other people in this call" : "Nun hai más xente nesta llamada",
+    "Send" : "Unviar",
+    "Error while sharing" : "Fallu entrín se compartía",
     "Waiting for {participantName} to join the call …" : "Esperando que {participantName} se xuna a la llamada...",
-    "Waiting for others to join the call …" : "Esperando que los otros se xunan a la llamada...",
     "WebRTC is not supported in your browser :-/" : "WebRTC nun ta sofitao nel to restolador :-/",
-    "Please use a different browser like Firefox or Chrome" : "Usa un restoador distintu como Firefox o Chrome, por favor",
     "Waiting for camera and microphone permissions" : "Esperando polos permisos del micrófonu y la cámara",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Da-y accesu al restolador pa que puea usar la to cámara y micrófonu, y usar esta aplicación.",
-    "Disable video" : "Deshabilitar videu",
+    "Mute audio" : "Silenciar audiu",
     "Share screen" : "Compartir pantalla",
-    "Show your screen" : "Amosar la to pantalla",
-    "Stop screensharing" : "Parar compartición de pantalla",
     "Screensharing is not supported by your browser." : "El to restolador nun sofita la compartición de pantalla.",
-    "Screensharing requires the page to be loaded through HTTPS." : "La compartición de pantalla rique que les páxines carguen pente HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la to pantalla namái funciona con Firefox 52 o más mayor.",
-    "Screensharing extension is required to share your screen." : "Ríquese la estensión de compartición de pantalla pa compartir la to pantalla",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Usa un restolador distintu como Firefox o Chrome pa compartir la to pantalla, por favor.",
-    "An error occurred while starting screensharing." : "Asocedió un fallu entrín s'aniciaba la compartición de pantalla.",
-    "Enable screensharing" : "Activar compartición de pantalla",
-    "Access to microphone & camera is only possible with HTTPS" : "L'accesu a la cámara y micrófonu namái ye posible con HTTPS",
-    "Access to microphone & camera was denied" : "Ñegóse l'accesu a la cámara y micrófonu",
-    "WebRTC is not supported in your browser" : "WebRTC nun ta sofitao nel to restolador",
-    "Error while accessing microphone & camera" : "Fallu entrín s'accedia al micrófonu y cámara",
+    "Favorited" : "Favoritos",
     "{participantName}'s screen" : "Pantalla de {participantName}",
     "Guest's screen" : "Pantalla de convidáu/ada",
-    "Your screen" : "La to pantalla",
     "_%n other guest_::_%n other guests_" : ["%n convidáu/ada más","%n convidaos/es más"],
     ", " : ", "
 },
