@@ -85,6 +85,10 @@ OC.L10N.register(
     "Conversation not found" : "Keskustelua ei löydy",
     "Path is already shared with this room" : "Polku on jo jaettu tämän huoneen kesken",
     "Chat, video & audio-conferencing using WebRTC" : "Keskustelu ja video- sekä äänineuvottelut WebRTC:tä käyttäen",
+    "Request password" : "Pyydä salasana",
+    "Error requesting the password." : "Virhe pyytäessä salasanaa.",
+    "This conversation has ended" : "Tämä keskustelu on päättynyt",
+    "None" : "Ei mitään",
     "User" : "Käyttäjä",
     "Everyone" : "Kaikki",
     "Disabled" : "Pois käytöstä",
@@ -99,19 +103,69 @@ OC.L10N.register(
     "UDP only" : "Vain UDP",
     "TCP only" : "Vain TCP",
     "Test this server" : "Testaa tämä palvelin",
-    "[Unknown user name]" : "[Tuntematon käyttäjänimi]",
     "Copy link" : "Kopioi linkki",
+    "No other people in this call" : "Ei muita henkilöitä tässä puhelussa",
+    "Waiting for others to join the call …" : "Odotetaan muiden liittymistä puheluun...",
+    "You can invite others in the participant tab of the sidebar" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta",
+    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta tai jakamalla tämän linkin!",
+    "Share this link to invite others!" : "Jaa tämä linkki kutsuaksesi muita!",
+    "Share whole screen" : "Jaa koko näyttö",
+    "Share a single window" : "Jaa yksittäinen ikkuna",
+    "Show your screen" : "Näytä oma näyttösi",
+    "Stop screensharing" : "Lopeta näytön jakaminen",
+    "No audio" : "Ei ääntä",
+    "Mute audio (m)" : "Mykistä äänet (m)",
+    "Unmute audio (m)" : "Palauta äänet (m)",
+    "Disable video (v)" : "Poista video käytöstä (v)",
+    "Enable video (v)" : "Ota video käyttöön (v)",
+    "Screensharing options" : "Näytönjakamisen valinnat",
+    "Enable screensharing" : "Ota käyttöön näytönjakaminen",
+    "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
+    "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea.",
+    "An error occurred while starting screensharing." : "Virhe aloitettaessa näytön jakamista.",
+    "Your screen" : "Sinun näyttösi",
+    "Show screen" : "Näytä näyttö",
+    "Disable video" : "Poista video käytöstä",
+    "Enable video" : "Käytä videota",
+    "Favorite" : "Suosikki",
     "Leave conversation" : "Poistu keskustelusta",
     "Delete conversation" : "Poista keskustelu",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
+    "Conversations" : "Keskustelut",
+    "Contacts" : "Yhteystiedot",
+    "Groups" : "Ryhmät",
+    "Circles" : "Piirit",
+    "Loading" : "Ladataan",
+    "Error" : "Virhe",
+    "Password protect" : "Suojaa salasanalla",
+    "Back" : "Takaisin",
+    "Close" : "Sulje",
+    "Conversation name" : "Keskustelun nimi",
+    "Reply" : "Vastaa",
+    "[Unknown user name]" : "[Tuntematon käyttäjänimi]",
+    "Today" : "Tänään",
+    "Yesterday" : "Eilen",
+    "File to share" : "Jaettava tiedosto",
     "moderator" : "moderaattori",
+    "guest" : "vieras",
     "Demote from moderator" : "Alenna moderaattorista",
     "Promote to moderator" : "Ylennä moderaattoriksi",
     "Remove participant" : "Poista osallistuja",
-    "Share link" : "Jaa linkki",
+    "No results" : "Ei tuloksia",
     "Participants" : "Osallistujat",
+    "Rename conversation" : "Nimeä keskustelu uudelleen",
+    "Guests" : "Vieraat",
+    "Share link" : "Jaa linkki",
+    "Password protection" : "Salasanasuojaus",
+    "Enter a password" : "Syötä salasana",
+    "Chat" : "Keskustelu",
     "Projects" : "Projektit",
+    "Edit" : "Muokkaa",
+    "Leave call" : "Poistu puhelusta",
+    "Start call" : "Aloita puhelu",
     "Limit to groups" : "Rajoita ryhmiin",
     "Guests can still join public conversations." : "Vieraat voivat silti liittyä julkisiin keskusteluihin.",
     "Limit app usage to groups." : "Rajoita sovelluksen käyttö ryhmiin.",
@@ -119,8 +173,10 @@ OC.L10N.register(
     "Saving …" : "Tallennetaan…",
     "Saved!" : "Tallennettu!",
     "Commands" : "Komennot",
+    "Beta" : "Beta",
     "Name" : "Nimi",
     "Command" : "Komento",
+    "General settings" : "Yleiset asetukset",
     "Saved" : "Tallennettu",
     "Add a new server" : "Lisää uusi palvelin",
     "Shared secret" : "Jaettu salaisuus",
@@ -131,14 +187,22 @@ OC.L10N.register(
     "Join a conversation or start a new one" : "Liity keskusteluun tai aloita uusi",
     "Say hi to your friends and colleagues!" : "Sano hei ystävillesi ja työkavereillesi!",
     "Link to a conversation" : "Linkki keskusteluun",
+    "Please enter the password for this call" : "Anna salasana tälle puhelulle",
+    "Password required" : "Salasana vaaditaan",
+    "Password" : "Salasana",
+    "Cancel" : "Peru",
+    "Submit" : "Lähetä",
+    "Access to microphone & camera is only possible with HTTPS" : "Kameran ja mikrofonin käyttäminen on mahdollista vain käytettäessä HTTPS-protokollaa",
+    "Please move your setup to HTTPS" : "Siirrä asetuksesi HTTPS:n taakse",
+    "Access to microphone & camera was denied" : "Yhteys mikrofoniin ja kameraan estettiin",
+    "WebRTC is not supported in your browser" : "WebRTC ei ole tuettuna selaimessasi",
+    "Please use a different browser like Firefox or Chrome" : "Käytä jotain toista selainta, kuten Firefoxia tai Chromea",
+    "Error while accessing microphone & camera" : "Virhe yhdistettäessä mikrofoniin ja kameraan",
     "This conversation is password-protected" : "Tämä keskustelu on salasanasuojattu",
     "The password is wrong. Try again." : "Salasana on väärin. Yritä uudelleen.",
-    "Password" : "Salasana",
-    "Fullscreen (f)" : "Koko näytön tila (f)",
     "TURN server" : "TURN-palvelin",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-palvelinta käytetään liikenteen välittämisessä palomuurin takana oleville osallistujille.",
     "%s Talk on your mobile devices" : "%s Keskustele mobiililaitteillasi",
-    "Join conversations at any time, any where, on any device." : "Liity keskusteluun milloin tahansa, mistä tahansa, miltä laitteelta tahansa.",
     "Android app" : "Android-sovellus",
     "iOS app" : "iOS-sovellus",
     "Delete server" : "Poista palvelin",
@@ -150,8 +214,8 @@ OC.L10N.register(
     "New group conversation" : "Uusi ryhmäkeskustelu",
     "{name} (public)" : "{name} (julkinen)",
     "New conversation …" : "Uusi keskustelu…",
-    "Chat" : "Keskustelu",
     "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
+    "Fullscreen (f)" : "Koko näytön tila (f)",
     "Set your name in the chat window so other participants can identify you better." : "Aseta nimesi keskusteluikkunassa, jotta muut osalliset tunnistavat sinut.",
     "Copy" : "Kopioi",
     "Copied!" : "Kopioitu!",
@@ -162,18 +226,9 @@ OC.L10N.register(
     "Start a conversation" : "Aloita keskustelu",
     "Share this file with others to discuss" : "Jaa tämä tiedosto toisten kanssa keskusteltavaksi",
     "Share" : "Jaa",
-    "Request password" : "Pyydä salasana",
-    "Error requesting the password." : "Virhe pyytäessä salasanaa.",
-    "Please enter the password for this call" : "Anna salasana tälle puhelulle",
-    "Password required" : "Salasana vaaditaan",
-    "Cancel" : "Peru",
-    "Submit" : "Lähetä",
-    "Leave call" : "Poistu puhelusta",
-    "Start call" : "Aloita puhelu",
     "Change password" : "Vaihda salasana",
     "Set password" : "Aseta salasana",
     "Go to file" : "Siirry tiedostoon",
-    "Conversation name" : "Keskustelun nimi",
     "Rename" : "Nimeä uudelleen",
     "Conversation with {name}" : "Keskustelu henkilön {name} kanssa",
     "Error occurred while setting password" : "Virhe salasanaa asettaessa",
@@ -182,62 +237,25 @@ OC.L10N.register(
     "No messages yet, start the conversation!" : "Ei vielä viestejä, aloita keskustelu!",
     "New message …" : "Uusi viesti …",
     "Send" : "Lähetä",
-    "Today" : "Tänään",
-    "Yesterday" : "Eilen",
     "The message you are trying to send is too long" : "Viesti, jonka yrität lähettää, on liian pitkä",
     "Error occurred while sending message" : "Viestiä lähettäessä tapahtui virhe",
-    "File to share" : "Jaettava tiedosto",
     "Error while sharing" : "Virhe jaettaessa",
-    "Edit" : "Muokkaa",
-    "No other people in this call" : "Ei muita henkilöitä tässä puhelussa",
     "Waiting for {participantName} to join the call …" : "Odotetaan henkilön {participantName} liittymistä puheluun...",
-    "Waiting for others to join the call …" : "Odotetaan muiden liittymistä puheluun...",
-    "You can invite others in the participant tab of the sidebar" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta",
-    "Share this link to invite others!" : "Jaa tämä linkki kutsuaksesi muita!",
-    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta tai jakamalla tämän linkin!",
     "WebRTC is not supported in your browser :-/" : "WebRTC ei ole tuettuna selaimessasi :-/",
-    "Please use a different browser like Firefox or Chrome" : "Käytä jotain toista selainta, kuten Firefoxia tai Chromea",
     "Waiting for camera and microphone permissions" : "Odotetaan käyttöoikeuden myöntämistä kameralle ja mikrofonille",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Anna selaimellesi oikeus käyttää kameraa ja mikrofonia käyttääksesi tätä sovellusta.",
-    "This conversation has ended" : "Tämä keskustelu on päättynyt",
     "Mute audio" : "Mykistä ääni",
-    "Disable video" : "Poista video käytöstä",
     "Share screen" : "Jaa näyttö",
-    "Share whole screen" : "Jaa koko näyttö",
-    "Share a single window" : "Jaa yksittäinen ikkuna",
-    "Show your screen" : "Näytä oma näyttösi",
-    "Stop screensharing" : "Lopeta näytön jakaminen",
-    "Unmute audio (m)" : "Palauta äänet (m)",
-    "Mute audio (m)" : "Mykistä äänet (m)",
-    "No audio" : "Ei ääntä",
-    "Enable video (v)" : "Ota video käyttöön (v)",
-    "Disable video (v)" : "Poista video käytöstä (v)",
     "No Camera" : "Ei kameraa",
     "Screensharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
-    "Screensharing options" : "Näytönjakamisen valinnat",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
-    "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea.",
-    "An error occurred while starting screensharing." : "Virhe aloitettaessa näytön jakamista.",
-    "Enable screensharing" : "Ota käyttöön näytönjakaminen",
     "Error while removing user from room" : "Virhe poistaessa käyttäjää huoneesta",
     "Add participant …" : "Lisää osallistuja…",
     "Favorited" : "Lisätty suosikkeihin",
     "Always notify" : "Ilmoita aina",
     "Notify on @-mention" : "Ilmoita @-maininnoista",
     "Never notify" : "Älä ilmoita koskaan",
-    "Close" : "Sulje",
-    "Show screen" : "Näytä näyttö",
-    "Enable video" : "Käytä videota",
-    "Access to microphone & camera is only possible with HTTPS" : "Kameran ja mikrofonin käyttäminen on mahdollista vain käytettäessä HTTPS-protokollaa",
-    "Please move your setup to HTTPS" : "Siirrä asetuksesi HTTPS:n taakse",
-    "Access to microphone & camera was denied" : "Yhteys mikrofoniin ja kameraan estettiin",
-    "WebRTC is not supported in your browser" : "WebRTC ei ole tuettuna selaimessasi",
-    "Error while accessing microphone & camera" : "Virhe yhdistettäessä mikrofoniin ja kameraan",
     "{participantName}'s screen" : "Henkilön {participantName} näyttö",
     "Guest's screen" : "Vieraan näyttö",
-    "Your screen" : "Sinun näyttösi",
     "_%n other guest_::_%n other guests_" : ["%n muu vieras","%n muuta vierasta"],
     ", " : ",",
     "Join now" : "Liity nyt",
@@ -257,6 +275,7 @@ OC.L10N.register(
     "Unnamed conversation" : "Nimetön keskustelu",
     "Video & audio-conferencing using WebRTC" : "Video- ja äänipuheluita WebRTC:tä käyttäen",
     "This call is password-protected" : "Tämä puhelu on salasanasuojattu",
+    "Join conversations at any time, any where, on any device." : "Liity keskusteluun milloin tahansa, mistä tahansa, miltä laitteelta tahansa.",
     "Enter name for a new conversation" : "Anna nimi uudelle keskustelulle",
     "Room name can not be empty" : "Huoneen nimi ei voi olla tyhjä",
     "Calls are disabled in this conversation." : "Puhelut on poistettu käytöstä tässä keskustelussa.",
