@@ -20,28 +20,30 @@ declare(strict_types=1);
  *
  */
 
-namespace OCA\Spreed\Chat\Command;
+namespace OCA\Talk\Chat\Command;
 
 
-use OCA\Spreed\Chat\ChatManager;
-use OCA\Spreed\Model\Command;
-use OCA\Spreed\Room;
-use OCA\Spreed\Service\CommandService;
+use OCA\Talk\Chat\ChatManager;
+use OCA\Talk\Events\CommandEvent;
+use OCA\Talk\Model\Command;
+use OCA\Talk\Room;
+use OCA\Talk\Service\CommandService;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\Comments\IComment;
+use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IL10N;
 use OCP\ILogger;
-use Symfony\Component\EventDispatcher\EventDispatcherInterface;
-use Symfony\Component\EventDispatcher\GenericEvent;
 
 class Executor {
 
+	public const EVENT_APP_EXECUTE = self::class . '::execApp';
+
 	public const PLACEHOLDER_ROOM = '{ROOM}';
 	public const PLACEHOLDER_USER = '{USER}';
 	public const PLACEHOLDER_ARGUMENTS = '{ARGUMENTS}';
 	public const PLACEHOLDER_ARGUMENTS_DOUBLEQUOTE_ESCAPED = '{ARGUMENTS_DOUBLEQUOTE_ESCAPED}';
 
-	/** @var EventDispatcherInterface */
+	/** @var IEventDispatcher */
 	protected $dispatcher;
 
 	/** @var ShellExecutor */
@@ -56,7 +58,7 @@ class Executor {
 	/** @var IL10N */
 	protected $l;
 
-	public function __construct(EventDispatcherInterface $dispatcher,
+	public function __construct(IEventDispatcher $dispatcher,
 								ShellExecutor $shellExecutor,
 								CommandService $commandService,
 								ILogger $logger,
@@ -171,21 +173,13 @@ class Executor {
 	}
 
 	protected function execApp(Room $room, IComment $message, Command $command, string $arguments): string {
-		$event = $this->createEvent($command);
-		$event->setArguments([
-			'room' => $room,
-			'message' => $message,
-			'arguments' => $arguments,
-			'output' => '',
-		]);
-
-		$this->dispatcher->dispatch(self::class . '::execApp', $event);
-
-		return (string) $event->getArgument('output');
+		$event = $this->createEvent($room, $message, $command, $arguments);
+		$this->dispatcher->dispatch(self::EVENT_APP_EXECUTE, $event);
+		return $event->getOutput();
 	}
 
-	protected function createEvent(Command $command): GenericEvent {
-		return new GenericEvent($command);
+	protected function createEvent(Room $room, IComment $message, Command $command, string $arguments): CommandEvent {
+		return new CommandEvent($room, $message, $command, $arguments);
 	}
 
 	public function execShell(Room $room, IComment $message, Command $command, string $arguments): string {
