@@ -20,7 +20,7 @@ declare(strict_types=1);
  *
  */
 
-namespace OCA\Spreed;
+namespace OCA\Talk;
 
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\IConfig;
@@ -102,6 +102,7 @@ class Config {
 		}
 
 		return [
+			'userId' => $userId,
 			'hideWarning' => !empty($signaling) || $this->getHideSignalingWarning(),
 			'server' => $signaling,
 			'ticket' => $this->getSignalingTicket($userId),
