@@ -24,20 +24,30 @@ declare(strict_types=1);
  *
  */
 
-namespace OCA\Spreed;
+namespace OCA\Talk;
 
-use OCA\Spreed\Exceptions\InvalidPasswordException;
-use OCA\Spreed\Exceptions\ParticipantNotFoundException;
-use OCA\Spreed\Exceptions\UnauthorizedException;
+use OCA\Talk\Events\AddParticipantsEvent;
+use OCA\Talk\Events\JoinRoomGuestEvent;
+use OCA\Talk\Events\JoinRoomUserEvent;
+use OCA\Talk\Events\ModifyLobbyEvent;
+use OCA\Talk\Events\ModifyParticipantEvent;
+use OCA\Talk\Events\ModifyRoomEvent;
+use OCA\Talk\Events\ParticipantEvent;
+use OCA\Talk\Events\RemoveParticipantEvent;
+use OCA\Talk\Events\RemoveUserEvent;
+use OCA\Talk\Events\RoomEvent;
+use OCA\Talk\Events\VerifyRoomPasswordEvent;
+use OCA\Talk\Exceptions\InvalidPasswordException;
+use OCA\Talk\Exceptions\ParticipantNotFoundException;
+use OCA\Talk\Exceptions\UnauthorizedException;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
 use OCP\DB\QueryBuilder\IQueryBuilder;
+use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IDBConnection;
 use OCP\IUser;
 use OCP\Security\IHasher;
 use OCP\Security\ISecureRandom;
-use Symfony\Component\EventDispatcher\EventDispatcherInterface;
-use Symfony\Component\EventDispatcher\GenericEvent;
 
 class Room {
 	public const UNKNOWN_CALL = -1;
@@ -56,13 +66,48 @@ class Room {
 	public const PARTICIPANT_REMOVED = 'remove';
 	public const PARTICIPANT_LEFT = 'leave';
 
+	public const EVENT_AFTER_ROOM_CREATE = self::class . '::createdRoom';
+	public const EVENT_BEFORE_ROOM_DELETE = self::class . '::preDeleteRoom';
+	public const EVENT_AFTER_ROOM_DELETE = self::class . '::postDeleteRoom';
+	public const EVENT_BEFORE_NAME_SET = self::class . '::preSetName';
+	public const EVENT_AFTER_NAME_SET = self::class . '::postSetName';
+	public const EVENT_BEFORE_PASSWORD_SET = self::class . '::preSetPassword';
+	public const EVENT_AFTER_PASSWORD_SET = self::class . '::postSetPassword';
+	public const EVENT_BEFORE_TYPE_SET = self::class . '::preSetType';
+	public const EVENT_AFTER_TYPE_SET = self::class . '::postSetType';
+	public const EVENT_BEFORE_READONLY_SET = self::class . '::preSetReadOnly';
+	public const EVENT_AFTER_READONLY_SET = self::class . '::postSetReadOnly';
+	public const EVENT_BEFORE_LOBBY_STATE_SET = self::class . '::preSetLobbyState';
+	public const EVENT_AFTER_LOBBY_STATE_SET = self::class . '::postSetLobbyState';
+	public const EVENT_BEFORE_USERS_ADD = self::class . '::preAddUsers';
+	public const EVENT_AFTER_USERS_ADD = self::class . '::postAddUsers';
+	public const EVENT_BEFORE_PARTICIPANT_TYPE_SET = self::class . '::preSetParticipantType';
+	public const EVENT_AFTER_PARTICIPANT_TYPE_SET = self::class . '::postSetParticipantType';
+	public const EVENT_BEFORE_USER_REMOVE = self::class . '::preRemoveUser';
+	public const EVENT_AFTER_USER_REMOVE = self::class . '::postRemoveUser';
+	public const EVENT_BEFORE_PARTICIPANT_REMOVE = self::class . '::preRemoveBySession';
+	public const EVENT_AFTER_PARTICIPANT_REMOVE = self::class . '::postRemoveBySession';
+	public const EVENT_BEFORE_ROOM_CONNECT = self::class . '::preJoinRoom';
+	public const EVENT_AFTER_ROOM_CONNECT = self::class . '::postJoinRoom';
+	public const EVENT_BEFORE_ROOM_DISCONNECT = self::class . '::preUserDisconnectRoom';
+	public const EVENT_AFTER_ROOM_DISCONNECT = self::class . '::postUserDisconnectRoom';
+	public const EVENT_BEFORE_GUEST_CONNECT = self::class . '::preJoinRoomGuest';
+	public const EVENT_AFTER_GUEST_CONNECT = self::class . '::postJoinRoomGuest';
+	public const EVENT_PASSWORD_VERIFY = self::class . '::verifyPassword';
+	public const EVENT_BEFORE_GUESTS_CLEAN = self::class . '::preCleanGuests';
+	public const EVENT_AFTER_GUESTS_CLEAN = self::class . '::postCleanGuests';
+	public const EVENT_BEFORE_SESSION_JOIN_CALL = self::class . '::preSessionJoinCall';
+	public const EVENT_AFTER_SESSION_JOIN_CALL = self::class . '::postSessionJoinCall';
+	public const EVENT_BEFORE_SESSION_LEAVE_CALL = self::class . '::preSessionLeaveCall';
+	public const EVENT_AFTER_SESSION_LEAVE_CALL = self::class . '::postSessionLeaveCall';
+
 	/** @var Manager */
 	private $manager;
 	/** @var IDBConnection */
 	private $db;
 	/** @var ISecureRandom */
 	private $secureRandom;
-	/** @var EventDispatcherInterface */
+	/** @var IEventDispatcher */
 	private $dispatcher;
 	/** @var ITimeFactory */
 	private $timeFactory;
@@ -91,6 +136,8 @@ class Room {
 	private $activeSince;
 	/** @var \DateTime|null */
 	private $lastActivity;
+	/** @var int */
+	private $lastMessageId;
 	/** @var IComment|null */
 	private $lastMessage;
 	/** @var string */
@@ -106,7 +153,7 @@ class Room {
 	public function __construct(Manager $manager,
 								IDBConnection $db,
 								ISecureRandom $secureRandom,
-								EventDispatcherInterface $dispatcher,
+								IEventDispatcher $dispatcher,
 								ITimeFactory $timeFactory,
 								IHasher $hasher,
 								int $id,
@@ -119,6 +166,7 @@ class Room {
 								int $activeGuests,
 								\DateTime $activeSince = null,
 								\DateTime $lastActivity = null,
+								int $lastMessageId,
 								IComment $lastMessage = null,
 								\DateTime $lobbyTimer = null,
 								string $objectType = '',
@@ -139,6 +187,7 @@ class Room {
 		$this->activeGuests = $activeGuests;
 		$this->activeSince = $activeSince;
 		$this->lastActivity = $lastActivity;
+		$this->lastMessageId = $lastMessageId;
 		$this->lastMessage = $lastMessage;
 		$this->lobbyTimer = $lobbyTimer;
 		$this->objectType = $objectType;
@@ -198,6 +247,13 @@ class Room {
 	}
 
 	public function getLastMessage(): ?IComment {
+		if ($this->lastMessageId && $this->lastMessage === null) {
+			$this->lastMessage = $this->manager->loadLastCommentInfo($this->lastMessageId);
+			if ($this->lastMessage === null) {
+				$this->lastMessageId = 0;
+			}
+		}
+
 		return $this->lastMessage;
 	}
 
@@ -284,10 +340,8 @@ class Room {
 	}
 
 	public function deleteRoom(): void {
-		$participants = $this->getParticipantsLegacy();
-		$this->dispatcher->dispatch(self::class . '::preDeleteRoom', new GenericEvent($this, [
-			'participants' => $participants,
-		]));
+		$event = new RoomEvent($this);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_ROOM_DELETE, $event);
 		$query = $this->db->getQueryBuilder();
 
 		// Delete all participants
@@ -300,9 +354,7 @@ class Room {
 			->where($query->expr()->eq('id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
 		$query->execute();
 
-		$this->dispatcher->dispatch(self::class . '::postDeleteRoom', new GenericEvent($this, [
-			'participants' => $participants,
-		]));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_ROOM_DELETE, $event);
 	}
 
 	/**
@@ -315,10 +367,8 @@ class Room {
 			return false;
 		}
 
-		$this->dispatcher->dispatch(self::class . '::preSetName', new GenericEvent($this, [
-			'newName' => $newName,
-			'oldName' => $oldName,
-		]));
+		$event = new ModifyRoomEvent($this, 'name', $newName, $oldName);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_NAME_SET, $event);
 
 		$query = $this->db->getQueryBuilder();
 		$query->update('talk_rooms')
@@ -327,10 +377,7 @@ class Room {
 		$query->execute();
 		$this->name = $newName;
 
-		$this->dispatcher->dispatch(self::class . '::postSetName', new GenericEvent($this, [
-			'newName' => $newName,
-			'oldName' => $oldName,
-		]));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_NAME_SET, $event);
 
 		return true;
 	}
@@ -346,9 +393,8 @@ class Room {
 
 		$hash = $password !== '' ? $this->hasher->hash($password) : '';
 
-		$this->dispatcher->dispatch(self::class . '::preSetPassword', new GenericEvent($this, [
-			'password' => $password,
-		]));
+		$event = new ModifyRoomEvent($this, 'password', $password);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_PASSWORD_SET, $event);
 
 		$query = $this->db->getQueryBuilder();
 		$query->update('talk_rooms')
@@ -357,9 +403,7 @@ class Room {
 		$query->execute();
 		$this->password = $hash;
 
-		$this->dispatcher->dispatch(self::class . '::postSetPassword', new GenericEvent($this, [
-			'password' => $password,
-		]));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_PASSWORD_SET, $event);
 
 		return true;
 	}
@@ -438,7 +482,7 @@ class Room {
 	 * @param int $newType Currently it is only allowed to change between `self::GROUP_CALL` and `self::PUBLIC_CALL`
 	 * @return bool True when the change was valid, false otherwise
 	 */
-	public function changeType(int $newType): bool {
+	public function setType(int $newType): bool {
 		if ($newType === $this->getType()) {
 			return true;
 		}
@@ -453,10 +497,8 @@ class Room {
 
 		$oldType = $this->getType();
 
-		$this->dispatcher->dispatch(self::class . '::preChangeType', new GenericEvent($this, [
-			'newType' => $newType,
-			'oldType' => $oldType,
-		]));
+		$event = new ModifyRoomEvent($this, 'type', $newType, $oldType);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_TYPE_SET, $event);
 
 		$query = $this->db->getQueryBuilder();
 		$query->update('talk_rooms')
@@ -475,10 +517,7 @@ class Room {
 			$query->execute();
 		}
 
-		$this->dispatcher->dispatch(self::class . '::postChangeType', new GenericEvent($this, [
-			'newType' => $newType,
-			'oldType' => $oldType,
-		]));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_TYPE_SET, $event);
 
 		return true;
 	}
@@ -504,10 +543,8 @@ class Room {
 			return false;
 		}
 
-		$this->dispatcher->dispatch(self::class . '::preSetReadOnly', new GenericEvent($this, [
-			'newState' => $newState,
-			'oldState' => $oldState,
-		]));
+		$event = new ModifyRoomEvent($this, 'readOnly', $newState, $oldState);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_READONLY_SET, $event);
 
 		$query = $this->db->getQueryBuilder();
 		$query->update('talk_rooms')
@@ -517,10 +554,7 @@ class Room {
 
 		$this->readOnly = $newState;
 
-		$this->dispatcher->dispatch(self::class . '::postSetReadOnly', new GenericEvent($this, [
-			'newState' => $newState,
-			'oldState' => $oldState,
-		]));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_READONLY_SET, $event);
 
 		return true;
 	}
@@ -549,12 +583,8 @@ class Room {
 			return false;
 		}
 
-		$this->dispatcher->dispatch(self::class . '::preSetLobbyState', new GenericEvent($this, [
-			'newState' => $newState,
-			'oldState' => $oldState,
-			'lobbyTimer' => $dateTime,
-			'timerReached' => $timerReached,
-		]));
+		$event = new ModifyLobbyEvent($this, 'lobby', $newState, $oldState, $dateTime, $timerReached);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_LOBBY_STATE_SET, $event);
 
 		$query = $this->db->getQueryBuilder();
 		$query->update('talk_rooms')
@@ -565,12 +595,7 @@ class Room {
 
 		$this->lobbyState = $newState;
 
-		$this->dispatcher->dispatch(self::class . '::postSetLobbyState', new GenericEvent($this, [
-			'newState' => $newState,
-			'oldState' => $oldState,
-			'lobbyTimer' => $dateTime,
-			'timerReached' => $timerReached,
-		]));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_LOBBY_STATE_SET, $event);
 
 		return true;
 	}
@@ -595,12 +620,11 @@ class Room {
 	}
 
 	/**
-	 * @param array[] ...$participants
+	 * @param array ...$participants
 	 */
 	public function addUsers(array ...$participants): void {
-		$this->dispatcher->dispatch(self::class . '::preAddUsers', new GenericEvent($this, [
-			'users' => $participants,
-		]));
+		$event = new AddParticipantsEvent($this, $participants);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_USERS_ADD, $event);
 
 		$lastMessage = 0;
 		if ($this->getLastMessage() instanceof IComment) {
@@ -628,55 +652,25 @@ class Room {
 			$query->execute();
 		}
 
-		$this->dispatcher->dispatch(self::class . '::postAddUsers', new GenericEvent($this, [
-			'users' => $participants,
-		]));
-	}
-
-	/**
-	 * @param string $participant
-	 * @param int $participantType
-	 */
-	public function setParticipantType(string $participant, int $participantType): void {
-		$this->dispatcher->dispatch(self::class . '::preSetParticipantType', new GenericEvent($this, [
-			'user' => $participant,
-			'newType' => $participantType,
-		]));
-
-		$query = $this->db->getQueryBuilder();
-		$query->update('talk_participants')
-			->set('participant_type', $query->createNamedParameter($participantType, IQueryBuilder::PARAM_INT))
-			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
-			->andWhere($query->expr()->eq('user_id', $query->createNamedParameter($participant)));
-		$query->execute();
-
-		$this->dispatcher->dispatch(self::class . '::postSetParticipantType', new GenericEvent($this, [
-			'user' => $participant,
-			'newType' => $participantType,
-		]));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_USERS_ADD, $event);
 	}
 
 	/**
 	 * @param Participant $participant
 	 * @param int $participantType
 	 */
-	public function setParticipantTypeBySession(Participant $participant, int $participantType): void {
-		$this->dispatcher->dispatch(self::class . '::preSetParticipantTypeBySession', new GenericEvent($this, [
-			'participant' => $participant,
-			'newType' => $participantType,
-		]));
+	public function setParticipantType(Participant $participant, int $participantType): void {
+		$event = new ModifyParticipantEvent($this, $participant, 'type', $participantType, $participant->getParticipantType());
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_PARTICIPANT_TYPE_SET, $event);
 
 		$query = $this->db->getQueryBuilder();
 		$query->update('talk_participants')
 			->set('participant_type', $query->createNamedParameter($participantType, IQueryBuilder::PARAM_INT))
 			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
-			->andWhere($query->expr()->eq('session_id', $query->createNamedParameter($participant->getSessionId())));
+			->andWhere($query->expr()->eq('user_id', $query->createNamedParameter($participant->getUser())));
 		$query->execute();
 
-		$this->dispatcher->dispatch(self::class . '::postSetParticipantTypeBySession', new GenericEvent($this, [
-			'participant' => $participant,
-			'newType' => $participantType,
-		]));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_PARTICIPANT_TYPE_SET, $event);
 	}
 
 	/**
@@ -690,11 +684,8 @@ class Room {
 			return;
 		}
 
-		$this->dispatcher->dispatch(self::class . '::preRemoveUser', new GenericEvent($this, [
-			'user' => $user,
-			'participant' => $participant,
-			'reason' => $reason,
-		]));
+		$event = new RemoveUserEvent($this, $participant, $user, $reason);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_USER_REMOVE, $event);
 
 		if ($this->getType() === self::ONE_TO_ONE_CALL) {
 			$this->setName($user->getUID());
@@ -706,11 +697,7 @@ class Room {
 			->andWhere($query->expr()->eq('user_id', $query->createNamedParameter($user->getUID())));
 		$query->execute();
 
-		$this->dispatcher->dispatch(self::class . '::postRemoveUser', new GenericEvent($this, [
-			'user' => $user,
-			'participant' => $participant,
-			'reason' => $reason,
-		]));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_USER_REMOVE, $event);
 
 	}
 
@@ -719,10 +706,8 @@ class Room {
 	 * @param string $reason
 	 */
 	public function removeParticipantBySession(Participant $participant, string $reason): void {
-		$this->dispatcher->dispatch(self::class . '::preRemoveBySession', new GenericEvent($this, [
-			'participant' => $participant,
-			'reason' => $reason,
-		]));
+		$event = new RemoveParticipantEvent($this, $participant, $reason);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_PARTICIPANT_REMOVE, $event);
 
 		$query = $this->db->getQueryBuilder();
 		$query->delete('talk_participants')
@@ -730,10 +715,7 @@ class Room {
 			->andWhere($query->expr()->eq('session_id', $query->createNamedParameter($participant->getSessionId())));
 		$query->execute();
 
-		$this->dispatcher->dispatch(self::class . '::postRemoveBySession', new GenericEvent($this, [
-			'participant' => $participant,
-			'reason' => $reason,
-		]));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_PARTICIPANT_REMOVE, $event);
 	}
 
 	/**
@@ -745,14 +727,10 @@ class Room {
 	 * @throws UnauthorizedException
 	 */
 	public function joinRoom(IUser $user, string $password, bool $passedPasswordProtection = false): string {
-		$event = new GenericEvent($this, [
-			'userId' => $user->getUID(),
-			'password' => $password,
-			'passedPasswordProtection' => $passedPasswordProtection,
-		]);
-		$this->dispatcher->dispatch(self::class . '::preJoinRoom', $event);
+		$event = new JoinRoomUserEvent($this, $user, $password, $passedPasswordProtection);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_ROOM_CONNECT, $event);
 
-		if ($event->hasArgument('cancel') && $event->getArgument('cancel') === true) {
+		if ($event->getCancelJoin() === true) {
 			$this->removeUser($user, self::PARTICIPANT_LEFT);
 			throw new UnauthorizedException('Participant is not allowed to join');
 		}
@@ -768,7 +746,7 @@ class Room {
 		$result = $query->execute();
 
 		if ($result === 0) {
-			if (!$passedPasswordProtection && !$this->verifyPassword($password)['result']) {
+			if (!$event->getPassedPasswordProtection() && !$this->verifyPassword($password)['result']) {
 				throw new InvalidPasswordException();
 			}
 
@@ -786,11 +764,7 @@ class Room {
 			$query->execute();
 		}
 
-		$this->dispatcher->dispatch(self::class . '::postJoinRoom', new GenericEvent($this, [
-			'userId' => $user->getUID(),
-			'password' => $password,
-			'passedPasswordProtection' => $passedPasswordProtection,
-		]));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_ROOM_CONNECT, $event);
 
 		return $sessionId;
 	}
@@ -806,11 +780,8 @@ class Room {
 			return;
 		}
 
-		$this->dispatcher->dispatch(self::class . '::preUserDisconnectRoom', new GenericEvent($this, [
-			'userId' => $userId,
-			'sessionId' => $sessionId,
-			'participant' => $participant,
-		]));
+		$event = new ParticipantEvent($this, $participant);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_ROOM_DISCONNECT, $event);
 
 		// Reset session when leaving a normal room
 		$query = $this->db->getQueryBuilder();
@@ -834,14 +805,9 @@ class Room {
 		if (!empty($sessionId)) {
 			$query->andWhere($query->expr()->eq('session_id', $query->createNamedParameter($sessionId)));
 		}
-		$selfJoined = (bool) $query->execute();
+		$query->execute();
 
-		$this->dispatcher->dispatch(self::class . '::postUserDisconnectRoom', new GenericEvent($this, [
-			'userId' => $userId,
-			'sessionId' => $sessionId,
-			'participant' => $participant,
-			'selfJoin' => $selfJoined,
-		]));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_ROOM_DISCONNECT, $event);
 	}
 
 	/**
@@ -852,14 +818,14 @@ class Room {
 	 * @throws UnauthorizedException
 	 */
 	public function joinRoomGuest(string $password, bool $passedPasswordProtection = false): string {
-		$event = new GenericEvent($this);
-		$this->dispatcher->dispatch(self::class . '::preJoinRoomGuest', $event);
+		$event = new JoinRoomGuestEvent($this, $password, $passedPasswordProtection);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_GUEST_CONNECT, $event);
 
-		if ($event->hasArgument('cancel') && $event->getArgument('cancel') === true) {
+		if ($event->getCancelJoin()) {
 			throw new UnauthorizedException('Participant is not allowed to join');
 		}
 
-		if (!$passedPasswordProtection && !$this->verifyPassword($password)['result']) {
+		if (!$event->getPassedPasswordProtection() && !$this->verifyPassword($password)['result']) {
 			throw new InvalidPasswordException();
 		}
 
@@ -880,28 +846,23 @@ class Room {
 			$sessionId = $this->secureRandom->generate(255);
 		}
 
-		$this->dispatcher->dispatch(self::class . '::postJoinRoomGuest', new GenericEvent($this));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_GUEST_CONNECT, $event);
 
 		return $sessionId;
 	}
 
-
-	public function changeInCall(string $sessionId, int $flags): void {
+	public function changeInCall(Participant $participant, int $flags): void {
+		$event = new ModifyParticipantEvent($this, $participant, 'inCall', $flags, $participant->getInCallFlags());
 		if ($flags !== Participant::FLAG_DISCONNECTED) {
-			$this->dispatcher->dispatch(self::class . '::preSessionJoinCall', new GenericEvent($this, [
-				'sessionId' => $sessionId,
-				'flags' => $flags,
-			]));
+			$this->dispatcher->dispatch(self::EVENT_BEFORE_SESSION_JOIN_CALL, $event);
 		} else {
-			$this->dispatcher->dispatch(self::class . '::preSessionLeaveCall', new GenericEvent($this, [
-				'sessionId' => $sessionId,
-			]));
+			$this->dispatcher->dispatch(self::EVENT_BEFORE_SESSION_LEAVE_CALL, $event);
 		}
 
 		$query = $this->db->getQueryBuilder();
 		$query->update('talk_participants')
 			->set('in_call', $query->createNamedParameter($flags, IQueryBuilder::PARAM_INT))
-			->where($query->expr()->eq('session_id', $query->createNamedParameter($sessionId)))
+			->where($query->expr()->eq('session_id', $query->createNamedParameter($participant->getSessionId())))
 			->andWhere($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
 
 		if ($flags !== Participant::FLAG_DISCONNECTED) {
@@ -913,14 +874,9 @@ class Room {
 		$query->execute();
 
 		if ($flags !== Participant::FLAG_DISCONNECTED) {
-			$this->dispatcher->dispatch(self::class . '::postSessionJoinCall', new GenericEvent($this, [
-				'sessionId' => $sessionId,
-				'flags' => $flags,
-			]));
+			$this->dispatcher->dispatch(self::EVENT_AFTER_SESSION_JOIN_CALL, $event);
 		} else {
-			$this->dispatcher->dispatch(self::class . '::postSessionLeaveCall', new GenericEvent($this, [
-				'sessionId' => $sessionId,
-			]));
+			$this->dispatcher->dispatch(self::EVENT_AFTER_SESSION_LEAVE_CALL, $event);
 		}
 	}
 
@@ -929,22 +885,19 @@ class Room {
 	 * @return array
 	 */
 	public function verifyPassword(string $password): array {
-		$event = new GenericEvent($this, [
-			'password' => $password
-		]);
+		$event = new VerifyRoomPasswordEvent($this, $password);
+		$this->dispatcher->dispatch(self::EVENT_PASSWORD_VERIFY, $event);
 
-		$this->dispatcher->dispatch(self::class . '::verifyPassword', $event);
-		if ($event->hasArgument('result')) {
-			$result = $event->getArgument('result');
+		if ($event->isPasswordValid() !== null) {
 			return [
-				'result' => $result['result'] ?? false,
-				'url' => $result['url'] ?? ''
+				'result' => $event->isPasswordValid(),
+				'url' => $event->getRedirectUrl(),
 			];
 		}
 
 		return [
 			'result' => !$this->hasPassword() || $this->hasher->verify($password, $this->password),
-			'url' => ''
+			'url' => '',
 		];
 	}
 
@@ -965,7 +918,8 @@ class Room {
 	}
 
 	public function cleanGuestParticipants(): void {
-		$this->dispatcher->dispatch(self::class . '::preCleanGuests', new GenericEvent($this));
+		$event = new RoomEvent($this);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_GUESTS_CLEAN, $event);
 
 		$query = $this->db->getQueryBuilder();
 		$query->delete('talk_participants')
@@ -974,7 +928,7 @@ class Room {
 			->andWhere($query->expr()->lte('last_ping', $query->createNamedParameter($this->timeFactory->getTime() - 100, IQueryBuilder::PARAM_INT)));
 		$query->execute();
 
-		$this->dispatcher->dispatch(self::class . '::postCleanGuests', new GenericEvent($this));
+		$this->dispatcher->dispatch(self::EVENT_AFTER_GUESTS_CLEAN, $event);
 	}
 
 	/**
