@@ -25,14 +25,19 @@ declare(strict_types=1);
  *
  */
 
-namespace OCA\Spreed\Share;
+namespace OCA\Talk\Share;
 
-use OCA\Spreed\Exceptions\ParticipantNotFoundException;
-use OCA\Spreed\Exceptions\RoomNotFoundException;
-use OCA\Spreed\Manager;
-use OCA\Spreed\Room;
+use OCA\Talk\Events\ParticipantEvent;
+use OCA\Talk\Events\RemoveUserEvent;
+use OCA\Talk\Events\RoomEvent;
+use OCA\Talk\Exceptions\ParticipantNotFoundException;
+use OCA\Talk\Exceptions\RoomNotFoundException;
+use OCA\Talk\Manager;
+use OCA\Talk\Participant;
+use OCA\Talk\Room;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\DB\QueryBuilder\IQueryBuilder;
+use OCP\EventDispatcher\IEventDispatcher;
 use OCP\Files\Folder;
 use OCP\Files\Node;
 use OCP\IDBConnection;
@@ -42,7 +47,6 @@ use OCP\Share\Exceptions\GenericShareException;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IManager as IShareManager;
 use OCP\Share\IShare;
-use OCP\Share\IShareHelper;
 use OCP\Share\IShareProvider;
 use Symfony\Component\EventDispatcher\EventDispatcherInterface;
 use Symfony\Component\EventDispatcher\GenericEvent;
@@ -95,38 +99,35 @@ class RoomShareProvider implements IShareProvider {
 		$this->l = $l;
 	}
 
-	public static function register(EventDispatcherInterface $dispatcher): void {
-		$listener = function(GenericEvent $event)  {
-			/** @var Room $room */
-			$room = $event->getSubject();
+	public static function register(IEventDispatcher $dispatcher): void {
+		$listener = static function(ParticipantEvent $event)  {
+			$room = $event->getRoom();
 
-			if ($event->getArgument('selfJoin')) {
+			if ($event->getParticipant()->getParticipantType() === Participant::USER_SELF_JOINED) {
 				/** @var self $roomShareProvider */
 				$roomShareProvider = \OC::$server->query(self::class);
-				$roomShareProvider->deleteInRoom($room->getToken(), $event->getArgument('userId'));
+				$roomShareProvider->deleteInRoom($room->getToken(), $event->getParticipant()->getUser());
 			}
 		};
-		$dispatcher->addListener(Room::class . '::postUserDisconnectRoom', $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_ROOM_DISCONNECT, $listener);
 
-		$listener = function(GenericEvent $event) {
-			/** @var Room $room */
-			$room = $event->getSubject();
+		$listener = static function(RemoveUserEvent $event) {
+			$room = $event->getRoom();
 
 			/** @var self $roomShareProvider */
 			$roomShareProvider = \OC::$server->query(self::class);
-			$roomShareProvider->deleteInRoom($room->getToken(), $event->getArgument('user')->getUID());
+			$roomShareProvider->deleteInRoom($room->getToken(), $event->getUser()->getUID());
 		};
-		$dispatcher->addListener(Room::class . '::postRemoveUser', $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_USER_REMOVE, $listener);
 
-		$listener = function(GenericEvent $event) {
-			/** @var Room $room */
-			$room = $event->getSubject();
+		$listener = static function(RoomEvent $event) {
+			$room = $event->getRoom();
 
 			/** @var self $roomShareProvider */
 			$roomShareProvider = \OC::$server->query(self::class);
 			$roomShareProvider->deleteInRoom($room->getToken());
 		};
-		$dispatcher->addListener(Room::class . '::postDeleteRoom', $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_ROOM_DELETE, $listener);
 	}
 
 	/**
@@ -167,6 +168,7 @@ class RoomShareProvider implements IShareProvider {
 		$existingShares = $this->getSharesByPath($share->getNode());
 		foreach ($existingShares as $existingShare) {
 			if ($existingShare->getSharedWith() === $share->getSharedWith()) {
+				// FIXME Should be moved away from GenericEvent as soon as OCP\Share20\IManager did move too
 				$this->dispatcher->dispatch(self::class . '::' . 'share_file_again', new GenericEvent($existingShare));
 				throw new GenericShareException('Already shared', $this->l->t('Path is already shared with this room'), 403);
 			}
@@ -223,7 +225,7 @@ class RoomShareProvider implements IShareProvider {
 	): int {
 		$qb = $this->dbConnection->getQueryBuilder();
 		$qb->insert('share')
-			->setValue('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM))
+			->setValue('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM))
 			->setValue('share_with', $qb->createNamedParameter($shareWith))
 			->setValue('uid_initiator', $qb->createNamedParameter($sharedBy))
 			->setValue('uid_owner', $qb->createNamedParameter($shareOwner))
@@ -281,6 +283,7 @@ class RoomShareProvider implements IShareProvider {
 			->setShareType((int)$data['share_type'])
 			->setPermissions((int)$data['permissions'])
 			->setTarget($data['file_target'])
+			->setStatus((int)$data['accepted'])
 			->setToken($data['token']);
 
 		$shareTime = $this->timeFactory->getDateTime();
@@ -530,7 +533,7 @@ class RoomShareProvider implements IShareProvider {
 				$qb->expr()->eq('item_type', $qb->createNamedParameter('folder'))
 			))
 			->andWhere(
-				$qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM))
+				$qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM))
 			);
 
 		/**
@@ -578,7 +581,7 @@ class RoomShareProvider implements IShareProvider {
 		$qb->select('*')
 			->from('share');
 
-		$qb->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM)));
+		$qb->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)));
 
 		/**
 		 * Reshares for this user are shares where they are the owner.
@@ -635,7 +638,7 @@ class RoomShareProvider implements IShareProvider {
 			->leftJoin('s', 'filecache', 'f', $qb->expr()->eq('s.file_source', 'f.fileid'))
 			->leftJoin('f', 'storages', 'st', $qb->expr()->eq('f.storage', 'st.numeric_id'))
 			->where($qb->expr()->eq('s.id', $qb->createNamedParameter($id)))
-			->andWhere($qb->expr()->eq('s.share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM)));
+			->andWhere($qb->expr()->eq('s.share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)));
 
 		$cursor = $qb->execute();
 		$data = $cursor->fetch();
@@ -731,7 +734,7 @@ class RoomShareProvider implements IShareProvider {
 		$cursor = $qb->select('*')
 			->from('share')
 			->andWhere($qb->expr()->eq('file_source', $qb->createNamedParameter($path->getId())))
-			->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM)))
+			->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)))
 			->execute();
 
 		$shares = [];
@@ -791,7 +794,7 @@ class RoomShareProvider implements IShareProvider {
 
 			$rooms = array_map(function(Room $room) { return $room->getToken(); }, $rooms);
 
-			$qb->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM)))
+			$qb->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)))
 				->andWhere($qb->expr()->in('share_with', $qb->createNamedParameter(
 					$rooms,
 					IQueryBuilder::PARAM_STR_ARRAY
@@ -852,7 +855,7 @@ class RoomShareProvider implements IShareProvider {
 
 		$cursor = $qb->select('*')
 			->from('share')
-			->where($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM)))
+			->where($qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)))
 			->andWhere($qb->expr()->eq('token', $qb->createNamedParameter($token)))
 			->execute();
 
@@ -926,7 +929,7 @@ class RoomShareProvider implements IShareProvider {
 
 		$qb = $this->dbConnection->getQueryBuilder();
 
-		$types = [\OCP\Share::SHARE_TYPE_ROOM];
+		$types = [IShare::TYPE_ROOM];
 		if ($currentAccess) {
 			$types[] = self::SHARE_TYPE_USERROOM;
 		}
@@ -944,7 +947,7 @@ class RoomShareProvider implements IShareProvider {
 		$users = [];
 		while($row = $cursor->fetch()) {
 			$type = (int)$row['share_type'];
-			if ($type === \OCP\Share::SHARE_TYPE_ROOM) {
+			if ($type === IShare::TYPE_ROOM) {
 				$roomToken = $row['share_with'];
 				try {
 					$room = $this->manager->getRoomByToken($roomToken);
@@ -1026,7 +1029,7 @@ class RoomShareProvider implements IShareProvider {
 		$qb->select('*')
 			->from('share')
 			->where($qb->expr()->eq('parent', $qb->createNamedParameter($parent->getId())))
-			->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM)))
+			->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)))
 			->orderBy('id');
 
 		$cursor = $qb->execute();
@@ -1045,7 +1048,7 @@ class RoomShareProvider implements IShareProvider {
 	 * received shares.
 	 *
 	 * Not part of IShareProvider API, but needed by the hooks in
-	 * OCA\Spreed\AppInfo\Application
+	 * OCA\Talk\AppInfo\Application
 	 *
 	 * @param string $roomToken
 	 * @param string|null $user
@@ -1055,7 +1058,7 @@ class RoomShareProvider implements IShareProvider {
 		$qb = $this->dbConnection->getQueryBuilder();
 		$qb->select('id')
 			->from('share')
-			->where($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM)))
+			->where($qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)))
 			->andWhere($qb->expr()->eq('share_with', $qb->createNamedParameter($roomToken)));
 
 		if ($user !== null) {
@@ -1082,7 +1085,7 @@ class RoomShareProvider implements IShareProvider {
 		// Now delete all the original room shares
 		$qb = $this->dbConnection->getQueryBuilder();
 		$qb->delete('share')
-			->where($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM)))
+			->where($qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)))
 			->andWhere($qb->expr()->eq('share_with', $qb->createNamedParameter($roomToken)));
 
 		if ($user !== null) {
@@ -1096,7 +1099,7 @@ class RoomShareProvider implements IShareProvider {
 			$qb = $this->dbConnection->getQueryBuilder();
 			$qb->select('id')
 				->from('share')
-				->where($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_ROOM)))
+				->where($qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)))
 				->andWhere($qb->expr()->eq('share_with', $qb->createNamedParameter($roomToken)));
 
 			$cursor = $qb->execute();
@@ -1119,4 +1122,30 @@ class RoomShareProvider implements IShareProvider {
 		}
 	}
 
+	/**
+	 * Get all the shares in this provider returned as iterable to reduce memory
+	 * overhead
+	 *
+	 * @return iterable
+	 * @since 18.0.0
+	 */
+	public function getAllShares(): iterable {
+		$qb = $this->dbConnection->getQueryBuilder();
+
+		$qb->select('*')
+			->from('share')
+			->where(
+				$qb->expr()->orX(
+					$qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM))
+				)
+			);
+
+		$cursor = $qb->execute();
+		while($data = $cursor->fetch()) {
+			$share = $this->createShareObject($data);
+
+			yield $share;
+		}
+		$cursor->closeCursor();
+	}
 }
